orca r3557 - trunk/test/keystrokes/firefox



Author: joanied
Date: Mon Feb 11 05:12:28 2008
New Revision: 3557
URL: http://svn.gnome.org/viewvc/orca?rev=3557&view=rev

Log:
Updated regression tests.


Modified:
   trunk/test/keystrokes/firefox/bug_511389.py
   trunk/test/keystrokes/firefox/html_role_combo_box.py
   trunk/test/keystrokes/firefox/html_role_links.py
   trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py
   trunk/test/keystrokes/firefox/label_guess_entries.py
   trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
   trunk/test/keystrokes/firefox/line_nav_enter_bug.py
   trunk/test/keystrokes/firefox/xul_role_alert.py
   trunk/test/keystrokes/firefox/xul_role_menu_bar.py
   trunk/test/keystrokes/firefox/xul_role_page_tab.py
   trunk/test/keystrokes/firefox/xul_role_push_button.py
   trunk/test/keystrokes/firefox/xul_role_tree.py
   trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py

Modified: trunk/test/keystrokes/firefox/bug_511389.py
==============================================================================
--- trunk/test/keystrokes/firefox/bug_511389.py	(original)
+++ trunk/test/keystrokes/firefox/bug_511389.py	Mon Feb 11 05:12:28 2008
@@ -54,7 +54,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Tab",
     ["BRAILLE LINE:  'Bar Link'",
-     "     VISIBLE:  'Bar Link', cursor=0",
+     "     VISIBLE:  'Bar Link', cursor=1",
+     "BRAILLE LINE:  'Bar Link'",
+     "     VISIBLE:  'Bar Link', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Bar link'"]))
 
@@ -67,7 +69,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Shift Tab",
     ["BRAILLE LINE:  'Foo Link'",
-     "     VISIBLE:  'Foo Link', cursor=0",
+     "     VISIBLE:  'Foo Link', cursor=1",
+     "BRAILLE LINE:  'Foo Link'",
+     "     VISIBLE:  'Foo Link', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Foo link'"]))
 

Modified: trunk/test/keystrokes/firefox/html_role_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/html_role_combo_box.py	Mon Feb 11 05:12:28 2008
@@ -62,7 +62,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Tab to Priority Link", 
     ["BRAILLE LINE:  'Priority Link : Normal Combo'",
-     "     VISIBLE:  'Priority Link : Normal Combo', cursor=0",
+     "     VISIBLE:  'Priority Link : Normal Combo', cursor=1",
+     "BRAILLE LINE:  'Priority Link : Normal Combo'",
+     "     VISIBLE:  'Priority Link : Normal Combo', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Priority link'"]))
 
@@ -73,7 +75,7 @@
     ["BRAILLE LINE:  'Priority Link : Normal Combo'",
      "     VISIBLE:  'Priority Link : Normal Combo', cursor=17",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Priority: Normal combo box'"]))
+     "SPEECH OUTPUT: 'Normal combo box'"]))
 
 ########################################################################
 # Press Tab once to get to the Resolution combo box.  This combo box
@@ -174,7 +176,7 @@
     "Return to collapse combo box",
     ["BRAILLE LINE:  'WONTFIX Combo'",
      "     VISIBLE:  'WONTFIX Combo', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Minefield frame about:blank internal frame'",
+     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test internal frame'",
      "SPEECH OUTPUT: 'Resolution: WONTFIX combo box'"]))
 
 ########################################################################
@@ -265,7 +267,7 @@
     "Return to collapse combo box",
     ["BRAILLE LINE:  'Braille Combo'",
      "     VISIBLE:  'Braille Combo', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Minefield frame about:blank internal frame'",
+     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test internal frame'",
      "SPEECH OUTPUT: 'Component Braille combo box'"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/html_role_links.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_links.py	(original)
+++ trunk/test/keystrokes/firefox/html_role_links.py	Mon Feb 11 05:12:28 2008
@@ -47,7 +47,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Tab to anchors.html link", 
     ["BRAILLE LINE:  'â anchors.html Link'",
-     "     VISIBLE:  'â anchors.html Link', cursor=0",
+     "     VISIBLE:  'â anchors.html Link', cursor=3",
+     "BRAILLE LINE:  'â anchors.html Link'",
+     "     VISIBLE:  'â anchors.html Link', cursor=3",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'anchors.html link'"]))
 
@@ -59,7 +61,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Tab to blockquotes.html link", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
-     "     VISIBLE:  'â blockquotes.html Link', cursor=0",
+     "     VISIBLE:  'â blockquotes.html Link', cursor=3",
+     "BRAILLE LINE:  'â blockquotes.html Link'",
+     "     VISIBLE:  'â blockquotes.html Link', cursor=3",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'blockquotes.html link'"]))
 
@@ -71,7 +75,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Tab to bugzilla_top.html link", 
     ["BRAILLE LINE:  'â bugzilla_top.html Link'",
-     "     VISIBLE:  'â bugzilla_top.html Link', cursor=0",
+     "     VISIBLE:  'â bugzilla_top.html Link', cursor=3",
+     "BRAILLE LINE:  'â bugzilla_top.html Link'",
+     "     VISIBLE:  'â bugzilla_top.html Link', cursor=3",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'bugzilla_top.html link'"]))
 
@@ -83,7 +89,9 @@
 sequence.append(utils.AssertPresentationAction(
     "Shift Tab to blockquotes.html link", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
-     "     VISIBLE:  'â blockquotes.html Link', cursor=0",
+     "     VISIBLE:  'â blockquotes.html Link', cursor=3",
+     "BRAILLE LINE:  'â blockquotes.html Link'",
+     "     VISIBLE:  'â blockquotes.html Link', cursor=3",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'blockquotes.html link'"]))
 
@@ -97,7 +105,7 @@
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
-     "     VISIBLE:  'â blockquotes.html Link', cursor=0",
+     "     VISIBLE:  'â blockquotes.html Link', cursor=3",
      "SPEECH OUTPUT: 'file link to blockquotes.html'",
      "SPEECH OUTPUT: 'same site'",
      "SPEECH OUTPUT: '1188 bytes'"]))

Modified: trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py	Mon Feb 11 05:12:28 2008
@@ -181,7 +181,7 @@
     ["BRAILLE LINE:  'Keywords Link : contains all of the keywords Combo  $l'",
      "     VISIBLE:  'contains all of the keywords Com', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Keywords: contains all of the keywords combo box'"]))
+     "SPEECH OUTPUT: 'Keywords contains all of the keywords combo box'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
@@ -402,7 +402,7 @@
     ["BRAILLE LINE:  'Only include Combo bugs numbered:  $l'",
      "     VISIBLE:  'Only include Combo bugs numbered', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'bugs numbered: Only include combo box'"]))
+     "SPEECH OUTPUT: 'Only include combo box'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
@@ -444,7 +444,7 @@
     ["BRAILLE LINE:  '[Bug creation] List'",
      "     VISIBLE:  '[Bug creation] List', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'where one or more of the following changed: [Bug creation] multi-select List with 26 items'"]))
+     "SPEECH OUTPUT: 'Alias [Bug creation] multi-select List with 26 items'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
@@ -487,7 +487,7 @@
     ["BRAILLE LINE:  'Sort results by: Reuse same sort as last time Combo'",
      "     VISIBLE:  'Reuse same sort as last time Com', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Sort results by: Reuse same sort as last time combo box'"]))
+     "SPEECH OUTPUT: 'Reuse same sort as last time combo box'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))

Modified: trunk/test/keystrokes/firefox/label_guess_entries.py
==============================================================================
--- trunk/test/keystrokes/firefox/label_guess_entries.py	(original)
+++ trunk/test/keystrokes/firefox/label_guess_entries.py	Mon Feb 11 05:12:28 2008
@@ -122,9 +122,10 @@
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
-    ["BRAILLE LINE:  ' $l '",
-     "     VISIBLE:  ' $l ', cursor=1",
-     "SPEECH OUTPUT: 'First Name text '"]))
+    ["BUG? - We're not guessing this correctly",
+     "BRAILLE LINE:  ' $l'",
+     "     VISIBLE:  ' $l', cursor=1",
+     "SPEECH OUTPUT: 'Sometimes labels can be below the fields due to <br /> text '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
@@ -132,9 +133,10 @@
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
-    ["BRAILLE LINE:  ' $l '",
+    ["BUG? - We're not guessing this correctly",
+     "BRAILLE LINE:  ' $l '",
      "     VISIBLE:  ' $l ', cursor=1",
-     "SPEECH OUTPUT: 'M.I. text '"]))
+     "SPEECH OUTPUT: 'text '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
@@ -142,9 +144,10 @@
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
-    ["BRAILLE LINE:  ' $l '",
+    ["BUG? - We're not guessing this correctly",
+     "BRAILLE LINE:  ' $l '",
      "     VISIBLE:  ' $l ', cursor=1",
-     "SPEECH OUTPUT: 'Last Name text '"]))
+     "SPEECH OUTPUT: 'text '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyPressAction(0, None, "KP_Insert"))

Modified: trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	Mon Feb 11 05:12:28 2008
@@ -455,14 +455,6 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  ' $l  and Now $l  '",
-     "     VISIBLE:  ' $l  and Now $l  ', cursor=0",
-     "SPEECH OUTPUT: 'Only bugs changed between: text '"]))
-
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
-    "Line Down",
     ["BRAILLE LINE:  '(YYYY-MM-DD or relative dates)'",
      "     VISIBLE:  '(YYYY-MM-DD or relative dates)', cursor=1",
      "SPEECH OUTPUT: '(YYYY-MM-DD or relative dates)'"]))
@@ -762,8 +754,8 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  ' $l  and Now $l'",
-     "     VISIBLE:  ' $l  and Now $l', cursor=1",
+    ["BRAILLE LINE:  ' $l  and Now $l  '",
+     "     VISIBLE:  ' $l  and Now $l  ', cursor=1",
      "SPEECH OUTPUT: 'Only bugs changed between: text   and text Now'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_enter_bug.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_enter_bug.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_enter_bug.py	Mon Feb 11 05:12:28 2008
@@ -160,8 +160,8 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'Description:  $l  '",
-     "     VISIBLE:  'Description:  $l  ', cursor=1",
+    ["BRAILLE LINE:  'Description:  $l'",
+     "     VISIBLE:  'Description:  $l', cursor=1",
      "SPEECH OUTPUT: 'Description: text '"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -323,8 +323,8 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  'Description:  $l  '",
-     "     VISIBLE:  'Description:  $l  ', cursor=1",
+    ["BRAILLE LINE:  'Description:  $l'",
+     "     VISIBLE:  'Description:  $l', cursor=1",
      "SPEECH OUTPUT: 'Description: text '"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_role_alert.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_alert.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_alert.py	Mon Feb 11 05:12:28 2008
@@ -26,16 +26,17 @@
 sequence.append(KeyComboAction("Return"))
 sequence.append(utils.AssertPresentationAction(
     "Press Return to make the alert appear",
+    ["BUG? - It seems that the internal frame may be causing us to not speak the alert",
     ["BRAILLE LINE:  'about:blank HtmlPane'",
      "     VISIBLE:  'about:blank HtmlPane', cursor=1",
      "BRAILLE LINE:  'Minefield Application [JavaScript Application] Dialog'",
      "     VISIBLE:  '[JavaScript Application] Dialog', cursor=1",
      "BRAILLE LINE:  'Minefield Application [JavaScript Application] Dialog OK Button'",
      "     VISIBLE:  'OK Button', cursor=1",
-     "SPEECH OUTPUT: 'about:blank panel'",
+     "SPEECH OUTPUT: 'about:blank internal frame'",
      "SPEECH OUTPUT: 'about:blank html content'",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: '[JavaScript Application] I am an alert'",
+     "SPEECH OUTPUT: '[JavaScript Application] '",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'OK button'"]))
 

Modified: trunk/test/keystrokes/firefox/xul_role_menu_bar.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_menu_bar.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_menu_bar.py	Mon Feb 11 05:12:28 2008
@@ -55,12 +55,12 @@
 sequence.append(utils.AssertPresentationAction(
     "Right Arrow on menu bar",
     ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
+     "     VISIBLE:  'View Menu', cursor=1",
      "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Toolbars Menu'",
      "     VISIBLE:  'Toolbars Menu', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'View menu'",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Toolbars menu'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -79,10 +79,14 @@
 sequence.append(KeyComboAction("Left"))
 sequence.append(utils.AssertPresentationAction(
     "Left Arrow on menu bar",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Toolbars Menu'",
+    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
+     "     VISIBLE:  'Location  $l', cursor=10",
+     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Toolbars Menu'",
      "     VISIBLE:  'Toolbars Menu', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Minefield frame View menu'",
-     "SPEECH OUTPUT: 'Toolbars menu'"]))
+     "SPEECH OUTPUT: 'Location autocomplete'",
+     "SPEECH OUTPUT: 'Location text '",
+     "SPEECH OUTPUT: 'View menu'",
+     "SPEECH OUTPUT: 'Toolbars menu'",]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Left"))

Modified: trunk/test/keystrokes/firefox/xul_role_page_tab.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_page_tab.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_page_tab.py	Mon Feb 11 05:12:28 2008
@@ -34,7 +34,7 @@
      "     VISIBLE:  'General Page', cursor=1",
      "SPEECH OUTPUT: 'tab list'",
      "SPEECH OUTPUT: 'General page'",
-     "SPEECH OUTPUT: 'item 1 of 3'",
+     "SPEECH OUTPUT: 'item 1 of 5'",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################
@@ -61,7 +61,7 @@
      "     VISIBLE:  'Page Setup Page', cursor=1",
      "SPEECH OUTPUT: 'tab list'",
      "SPEECH OUTPUT: 'Page Setup page'",
-     "SPEECH OUTPUT: 'item 2 of 3'",
+     "SPEECH OUTPUT: 'item 2 of 5'",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/xul_role_push_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_tree.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_tree.py	Mon Feb 11 05:12:28 2008
@@ -207,7 +207,8 @@
      "     VISIBLE:  'Bookmarks Toolbar   TREE LEVEL 1', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Name column header'",
-     "SPEECH OUTPUT: 'Bookmarks Toolbar  '"]))
+     "SPEECH OUTPUT: 'Bookmarks Toolbar  '",
+     "SPEECH OUTPUT: ' not selected'"]))
 
 ########################################################################
 # Now that the Places Manager is back to its pre-explored state,

Modified: trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py	(original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py	Mon Feb 11 05:12:28 2008
@@ -70,7 +70,7 @@
      "     VISIBLE:  'Who expects the Spanish Inquisit', cursor=1",
      "BRAILLE LINE:  'Who expects the Spanish Inquisition? Button'",
      "     VISIBLE:  'Who expects the Spanish Inquisit', cursor=1",
-     "SPEECH OUTPUT: 'Minefield'",
+     "SPEECH OUTPUT: 'Status Bar Regression Test - Minefield'",
      "SPEECH OUTPUT: 'NOBODY expects the Spanish Inquisition!'"]))
 
 ########################################################################



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/test/keystrokes/firefox/xul_role_push_button.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_push_button.py	Mon Feb 11 05:12:28 2008
@@ -29,10 +29,10 @@
 sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
 sequence.append(utils.AssertPresentationAction(
     "Shift+Tab to button",
-    ["BRAILLE LINE:  'Minefield Application Print Dialog Cancel Button'",
-     "     VISIBLE:  'Cancel Button', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Print Button'",
+     "     VISIBLE:  'Print Button', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Cancel button'"]))
+     "SPEECH OUTPUT: 'Print button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -42,17 +42,17 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Print Dialog Cancel Button'",
-     "     VISIBLE:  'Cancel Button', cursor=1",
-     "SPEECH OUTPUT: 'Cancel'",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Print Button'",
+     "     VISIBLE:  'Print Button', cursor=1",
+     "SPEECH OUTPUT: 'Print'",
      "SPEECH OUTPUT: 'button'",
-     "SPEECH OUTPUT: 'Alt c'"]))
+     "SPEECH OUTPUT: 'Alt p'"]))
 
 ########################################################################
 # Dismiss the dialog by pressing Space on the Cancel button and wait 
 # for the location bar to regain focus.
 #
-sequence.append(TypeAction(" "))
+sequence.append(TypeAction("Escape"))
 sequence.append(WaitForWindowActivate("Minefield",None))
 
 # Just a little extra wait to let some events get through.
@@ -42,17 +42,17 @@
 
 ########################################################################
-# Dismiss the dialog by pressing Space on the Cancel button and wait 
-# for the location bar to regain focus.
+# Dismiss the dialog by pressing Escape and wait for the location bar
+# to regain focus.
 #

Modified: trunk/test/keystrokes/firefox/xul_role_tree.py
==============================================================================